@@ -1,5 +1,5 @@
-require 'puppet/resource/catalog'
-require 'puppet/indirector/json'
+require_relative '../../../puppet/resource/catalog'
+require_relative '../../../puppet/indirector/json'
 
 class Puppet::Resource::Catalog::Json < Puppet::Indirector::JSON
   desc "Store catalogs as flat files, serialized using JSON."
@@ -18,9 +18,14 @@ class Puppet::Resource::Catalog::Json < Puppet::Indirector::JSON
   def to_json(object)
     object.render(json_format)
   rescue Puppet::Network::FormatHandler::FormatError => err
-    Puppet.info(_("Unable to serialize catalog to json, retrying with pson"))
-    Puppet.log_exception(err, err.message, level: :debug)
-    object.render('pson').force_encoding(Encoding::BINARY)
+    if Puppet[:allow_pson_serialization]
+      Puppet.info(_("Unable to serialize catalog to json, retrying with pson. PSON is deprecated and will be removed in a future release"))
+      Puppet.log_exception(err, err.message, level: :debug)
+      object.render('pson').force_encoding(Encoding::BINARY)
+    else
+      Puppet.info(_("Unable to serialize catalog to json, no other acceptable format"))
+      Puppet.log_exception(err, err.message, level: :err)
+    end
   end
 
   private
